(function ($, Drupal) {
  'use strict';

  Drupal.behaviors.textClarityChecker = {
    attach: function (context, settings) {

      once('textClarityChecker', '#text-clarity-checker', context).forEach(function (modal) {
        const node = document.querySelector('.node');

        if (!modal) {
          return;
        }

        const metrics = {
          textLength: 0,
          imageCount: 0,
          decorativeImageCount: 0,
          paragraphCount: 0,
          averageParagraphLength: 0,
          readingTime: 0,
          hasH1: false,
          hasValidHeadingStructure: true,
          backgroundImageCount: 0,
          elementCount: 0,
          internalLinkCount: 0,
          externalLinkCount: 0,
          headingDepth: 0,
          estimatedLoadTime: 0
        };

        try {
          const textContent = node.textContent.trim();
          metrics.textLength = textContent.split(/\s+/).length;
          metrics.readingTime = Math.ceil(metrics.textLength / 200);

          const images = Array.from(node.getElementsByTagName('img'));
          metrics.imageCount = images.length;

          images.forEach(img => {
            const altText = img.alt.trim();
            if (!altText || altText.split(/\s+/).length < 5) {
              metrics.decorativeImageCount++;
              metrics.readingTime += 2;
            } else {
              metrics.readingTime += Math.ceil(altText.split(/\s+/).length / 200);
            }
          });

          // Éléments et images de fond
          const allElements = node.querySelectorAll('*');
          allElements.forEach(element => {
            const style = window.getComputedStyle(element);
            if (style.backgroundImage !== 'none') {
              metrics.backgroundImageCount++;
            }
          });

          metrics.elementCount = allElements.length;
          metrics.paragraphCount = node.getElementsByTagName('p').length;
          metrics.hasH1 = !!node.querySelector('h1');

          // Structure des titres
          const headings = Array.from(node.querySelectorAll('h1, h2, h3, h4, h5, h6'));
          metrics.hasValidHeadingStructure = checkHeadingStructure(headings);
          if (headings.length > 0) {
            metrics.headingDepth = Math.max(...headings.map(h => parseInt(h.tagName.replace('H', ''), 10)));
          }

          // Paragraphes
          const paragraphs = Array.from(node.getElementsByTagName('p'));
          if (paragraphs.length > 0) {
            const totalParagraphLength = paragraphs.reduce((sum, p) => sum + p.textContent.trim().split(/\s+/).length, 0);
            metrics.averageParagraphLength = totalParagraphLength / paragraphs.length;
          }

          // Liens
          const links = Array.from(node.getElementsByTagName('a'));
          links.forEach(link => {
            const href = link.getAttribute('href');
            if (href && href.startsWith(window.location.origin)) {
              metrics.internalLinkCount++;
            } else if (href && href.startsWith('http')) {
              metrics.externalLinkCount++;
            }
          });

          metrics.estimatedLoadTime = (metrics.imageCount * 0.5) + (metrics.elementCount * 0.01);

          const score = calculateUXScore(metrics);
          updateMetrics(metrics, score);
          updateScoreCircle(score);
          setupModalToggle(modal, score);

        } catch (error) {}
      });
    }
  };

  function calculateUXScore(metrics) {
    let score = 100;

    if (metrics.textLength > 1000) score -= 10;
    if (metrics.imageCount < 1) score -= 15;
    if (metrics.paragraphCount < 3) score -= 10;
    if (metrics.averageParagraphLength > 80) score -= 10;
    if (!metrics.hasValidHeadingStructure) score -= 20;
    if (metrics.elementCount > 50) score -= 10;
    if (metrics.headingDepth > 4) score -= 5;
    if (metrics.externalLinkCount > metrics.internalLinkCount) score -= 5;

    return Math.max(0, score);
  }

  function checkHeadingStructure(headings) {
    if (headings.length === 0) return true;

    let lastLevel = 0;
    for (const heading of headings) {
      const level = parseInt(heading.tagName.replace('H', ''), 10);
      if (lastLevel && level > lastLevel + 1) {
        return false;
      }
      lastLevel = level;
    }
    return true;
  }

  function updateMetrics(metrics, score) {
    try {
      const elements = {
        '.metric-text': metrics.textLength,
        '.metric-reading': `${metrics.readingTime} min`,
        '.metric-img': metrics.imageCount,
        '.metric-decorative-img': metrics.decorativeImageCount,
        '.metric-background-img': metrics.backgroundImageCount,
        '.metric-element': metrics.elementCount,
        '.metric-paragraph': metrics.paragraphCount,
        '.metric-paragraph-len': metrics.averageParagraphLength.toFixed(2),
        '.metric-valid-title': metrics.hasValidHeadingStructure ? 'Yes' : 'No',
        '.metric-heading-depth': metrics.headingDepth,
        '.metric-internal-links': metrics.internalLinkCount,
        '.metric-external-links': metrics.externalLinkCount,
        '.metric-load-time': `${metrics.estimatedLoadTime.toFixed(2)} sec`,
        '#score': score
      };

      Object.entries(elements).forEach(([selector, value]) => {
        const element = document.querySelector(selector);
        if (element) {
          element.textContent = element.textContent.split(':')[0] + ': ' + value;
        }
      });
    } catch (error) {
    }
  }

  function updateScoreCircle(score) {
    try {
      const scoreCircle = document.querySelector('.score-circle');
      if (!scoreCircle) {
        return;
      }

      const startColor = { r: 193, g: 26, b: 14 };
      const endColor = { r: 6, g: 169, b: 44 };

      const r = Math.floor(startColor.r + (endColor.r - startColor.r) * (score / 100));
      const g = Math.floor(startColor.g + (endColor.g - startColor.g) * (score / 100));
      const b = Math.floor(startColor.b + (endColor.b - startColor.b) * (score / 100));

      scoreCircle.style.backgroundColor = `rgb(${r}, ${g}, ${b})`;
    } catch (error) {
    }
  }

  function setupModalToggle(modal, score) {
    try {
      const scorePastille = document.querySelector('#score-pastille');
      if (!scorePastille) {
        return;
      }

      scorePastille.textContent = score;
      
      scorePastille.addEventListener('click', () => {
        modal.classList.toggle('show');
      });
    } catch (error) {
    }
  }

})(jQuery, Drupal);
